
; INDISIM - PARACOCCUS SIMULATOR - Metabolic version
; Araujo Granda P.A., Gras A., Ginovart M. & Moulton V. - 2016
;______________________________ Global Variables __________________________________________________________________________________

globals
[
  world                                                                      ; culture medium continuos size [ litres ]
  steptime                                                                   ; step time [h]
  time_now                                                                   ; simulated time [hours]
  gbacteria gdioxide gbicarbonate gn2o gno2- gno gn2 gsuccinate gamonium gnitrate goxygen ; global variables for graphical and numerical outputs
  output_file                                                                ; global variable for output file
  DST DSTb DSTr                                                              ; Variables for General Standard Deviation
  succinatemedium amoniummedium oxygenmedium nitratemedium nitritemedium monoxidemedium dinitrogenmedium nitrogenmedium dioxidemedium bicarbonatemedium
  succinate-input amonium-input nitrate-input
  xsc xam xox xntr xnr xmn xdn xn2 xco2 xhco3 bacteriaout xbacteria
  d
  untri
  isuccinate iamonium ioxygen initrate initrite imonoxide idinitrogen initrogen idioxide ibicarbonate ibacteria icbacteria inbacteria
  fsuccinate famonium foxygen fnitrate fnitrite fmonoxide fdinitrogen fnitrogen fdioxide fbicarbonate fbacteria fcbacteria fnbacteria
  insuccinate inamonium innitrate
  outsuccinate outamonium outoxygen outnitrate outnitrite outmonoxide outdinitrogen outnitrogen outdioxide outbicarbonate outbacteria outcbacteria outnbacteria
  c-bacteria n-bacteria c-succinate n-amonium n-nitrate n-nitrite n-monoxide n-dinitrogen n-nitrogen c-co2 c-hco3
  n-obtained n-delivered c-obtained c-delivered
  %_e_c %_e_n yc/c
  scm oxm ntrm
  q
  sc-mant2 sc-mant3 sc-mant4
  ini_biomass rep_biomass
  Suc Amo Oxy Nrt Nit N2O
  Pablo Araujo
  ]

; ____________________________ Microorganism variables ____________________________________________________________________________

breed [bacteria bacterium]                                                   ; microorganism definition
bacteria-own
[
  biomass                                                                    ; microorganism biomass [ mmol ]
  biomass-reproduction                                                       ; reproduction treshold biomass [ mmol ]
  R                                                                          ; reproductions counter
  m_aero s_aero_1 s_aero_2                                                   ; aerobic phase counter
  m_anox_1 m_anox_2 m_anox_3 m_anox_4 s_anox_1 s_anox_2 s_anox_3 s_anox_4    ; anaerobic reactions counters
  sc-useful am-useful ox-useful ntr-useful nr-useful mn-useful dn-useful     ; usefuls nutrients variables
]

; ____________________________ Culture Medium variables ____________________________________________________________________________

patches-own [
  succinate-medium                     ; culture medium variable for the electron donor and C-Source in aerobic and anaerobic phases [ mmol ]
  amonium-medium                       ; culture medium variable for the N-Source in aerobic and anaerobic phases [ mmol ]
  oxygen-medium                        ; culture medium variable for the electron aceptor in aerobic phase [ mmol ]
  nitrate-medium                       ; culture medium variable for the electron aceptor in anoxic reaction 1 [ mmol ]
  nitrite-medium                       ; culture medium variable for the electron aceptor in anoxic reaction 2 [ mmol ]
  monoxide-medium                      ; culture medium variable for the electron aceptor in anoxic reaction 3 [ mmol ]
  dinitrogen-medium                    ; culture medium variable for the electron aceptor in anoxic reaction 4 [ mmol ]
  dioxide nitrogen bicarbonate         ; culture medium variables for the denitrification products [ mmol ]
    ]

; ____________________________ Virtual Bioreactor Setting ____________________________________________________________________________

to setup
  clear-all                      ; clear all variables, graphical and numerical outputs
  reset-timer                    ; reset the timer counter
  reset-ticks                    ; reset tick counter
  setup-model                    ; setup general model parameters to obtain the starting points accord to Felgate's (2012) experiment
  setup-time                     ; scaled time setting
  setup-medium                   ; formulation of the initial culture medium
  setup-bacteria                 ; formulation of initial bacterial inoculum
  setup-monitors                 ; monitors setting
  if Output_file? = true
  [
  setup-output                   ; setup output file
  write-outputfile               ; write initial values on output file
  ]
  setup-balance                  ; mass balance setup
end

;_____________________________ Initial data according to Felgate's Experiments _____________________________________________________

to setup-model
  set world (world-width * world-height)              ; Differential adjustment of reactor volume
  set DSTb 0.15                                       ; Standard Deviation for initial biomass distribution
  set DSTr 0.15                                       ; Standard Deviation for biomass reproduction
  set DST 0.05                                        ; Standard Deviation for general model varaibles
  set ini_biomass abs random-normal (4.5) (DST * 4.5) ; [pmol] initial biomass per each bacterium
  set rep_biomass abs random-normal (4.5) (DST * 4.5) ; [pmol] reproduction treshold biomass
if Experiment = "Succ_High/Nitrate_Low"
[
  Set Succinate 20 Set Nitrate 4.99825                                ; Succiante and Nitrate setup accord to Felgate's (2012) experiment (Succinate High/Nitrate low)
  let initial_biomass abs random-normal (0.0033683) (DST * 0.0033683)
  set Microrganism round ((initial_biomass * 1000 * world) / (75 * ini_biomass)) ; this quantity fix the initial biomass concentration accord to Felgate's (2012) experiment.

]
if Experiment = "Succ_Low/Nitrate_High"
[
  Set Succinate 5 set Nitrate 21.60951                                ; Succiante and Nitrate setup accord to Felgate's (2012) experiment (Succinate Low/Nitrate high)
  let initial_biomass abs random-normal (0.0668478) (DST * 0.0668478)
  set Microrganism round ((initial_biomass * 1000 * world) / (75 * ini_biomass)) ; this quantity fix the initial biomass concentration accord to Felgate's (2012) experiment.
]
end

; ____________________________ Proceeding to Scaled time ____________________________________________________________________________

to setup-time
  set steptime (Min/steptime / 60)       ; User define the number of minute for each step time using a slider labeled "Min_per_steptime"
end

; ____________________________ Proceeding to Formulation of Initial culture medium __________________________________________________

to setup-medium
if Experiment = "Succ_High/Nitrate_Low"
       [
       set Suc random-normal (Succinate) (DST * Succinate)           ; Succinate initial concentration (user define using a slider labeled Succinate) [mM]
       set Amo random-normal (Amonium) (DST * Amonium)               ; Amonium initial concentration (user define using a slider labeled Amonium) [mM]
       set Oxy random-normal (0.2360) (DST * 0.2360)                 ; Oxygen initial concentration (simulated saturated conditions) accord to Felgate's (2012) experiment [mM]
       set Nrt random-normal (Nitrate) (DST * Nitrate)               ; Nitrate initial concentration (user define using a slider labeled Nitrate) [mM]
       set Nit random-normal (0.0255) (DST * 0.0255)                 ; Nitrite initial concentration accord to Felgate's (2012) experiment [mM]
       set N2O random-normal (0.003003178) (DST * 0.003003178)       ; Nitrous oxide initial concentration accord to Felgate's (2012) experiment [mM]
       ]
     if Experiment = "Succ_Low/Nitrate_High"
       [
       set Suc random-normal (Succinate) (DST * Succinate)           ; Succinate initial concentration (user define using a slider labeled Succinate) [mM]
       set Amo random-normal (Amonium) (DST * Amonium)               ; Amonium initial concentration (user define using a slider labeled Amonium) [mM]
       set Oxy random-normal (0.2360) (DST * 0.2360)                 ; Oxygen initial concentration (simulated saturated conditions) accord to Felgate's (2012) experiment [mM]
       set Nrt random-normal (Nitrate) (DST * Nitrate)               ; Nitrate initial concentration (user define using a slider labeled Nitrate) [mM]
       set Nit random-normal (0.011163522) (DST * 0.011163522)       ; Nitrite initial concentration accord to Felgate's (2012) experiment [mM]
       set N2O random-normal (0.000028413312) (DST * 0.000028413312) ; Nitrous oxide initial concentration accord to Felgate's (2012) experiment [mM]
       ]
   ask patches
   [
     set succinate-medium abs random-normal (Suc) (DST * Suc)            ; Assign the succinate concentration to each cell according to the model's standar deviation
     set amonium-medium abs random-normal (Amo) (DST * Amo)              ; Assign the amonium concentration to each cell according to the model's standar deviation
     set oxygen-medium  abs random-normal (Oxy) (DST * Oxy)              ; Assign the oxygen concentration to each cell according to the model's standar deviation
     set nitrate-medium abs random-normal (Nrt) (DST * Nrt)              ; Assign the nitrate concentration to each cell according to the model's standar deviation
     set nitrite-medium abs random-normal (Nit) (DST * Nit)              ; Assign the nitrite concentration to each cell according to the model's standar deviation
     set dinitrogen-medium abs random-normal (N2O) (DST * N2O)           ; Assign the nitrous oxide concentration to each cell according to the model's standar deviation
     set monoxide-medium 0                                                ; Nitric Oxide initial concentration accord to Felgate's (2012) experiment [mM]
     set nitrogen 0                                                       ; Nitrogen gas (N2) initial concentration accord to Felgate's (2012) experiment [mM]
     set dioxide 0                                                        ; Carbon Dioxide initial concentration accord to Felgate's (2012) experiment [mM]
     set bicarbonate 0                                                    ; Bicarbonate initial concentration [mM]
     set pcolor scale-color blue succinate-medium 0 Succinate
   ]

end

; ____________________________ Proceeding to Formulation the Initial bacterial inoculum __________________________________________________

to setup-bacteria
 create-bacteria Microrganism                                    ; User define the amount of initial active bacteria using a slider labaled Microrganism
 [
   set shape "circle"                                            ; Paracoccus denitrificans is a spherical bacteria
   set size 0.5                                                  ; This size is for visual propouse only
   set color green                                               ; This color is for visual propouse only
   setxy random-xcor random-ycor                                 ; Random inicial position on culture medium
   set biomass abs random-normal (ini_biomass) (DSTb * ini_biomass)                  ; [ mmol] in order to P.denitrificans biomass elementary cell composition C3H5.4N0.75O1.45 (M = 75 mg/mmol)
   set biomass-reproduction abs random-normal (rep_biomass) (DSTr * rep_biomass) ; reproduction treshold biomass [ mmol ] accord to INDISIM general procedures.
 ]
end

; ____________________________ Proceeding to monitors setting __________________________________________________________________________

to setup-monitors
  set time_now ticks * steptime                                                                          ; Simulated time [ h ]
  set gbacteria ((sum [biomass] of bacteria / world) / 1000) * 75                                        ; Biomass concentration [ mg/ml ]
  set gsuccinate (sum[succinate-medium]of patches / world)                                               ; Succinate concentration [ mM ]
  set gamonium (sum [amonium-medium] of patches / world)                                                 ; Amonium concentration [ mM ]
  set goxygen (sum [oxygen-medium] of patches / world)                                                   ; Oxygen concentration [ mM ]
  set gnitrate (sum [nitrate-medium] of patches / world)                                                 ; Nitrate concentration [ mM ]
  set gno2- (sum [nitrite-medium] of patches / world)                                                    ; Nitrite concentration [ mM ]
  set gno (sum [monoxide-medium] of patches / world)                                                     ; Nitric Oxide concentration [ mM ]
  if Experiment = "Succ_Low/Nitrate_High"[set gn2o (sum [dinitrogen-medium] of patches / world) * 1000]  ; Nitrous Oxide concentration [ uM ]
  if Experiment = "Succ_High/Nitrate_Low"[set gn2o (sum [dinitrogen-medium] of patches / world)]         ; Nitrous Oxide concentration [ mM ]
  set gdioxide (sum [dioxide] of patches / world)                                                        ; Carbon dioxide concentration [ mM ]
  set gn2 (sum [nitrogen] of patches / world)                                                            ; Nitrogen concentration [ mM ]
  set gbicarbonate (sum [bicarbonate] of patches / world)                                                ; Bicarbonate concentration [ mM ]

  reactor_balance
end

; ____________________________ Proceeding to setup output file __________________________________________________________________________

to setup-output
  file-close
  if Experiment = "Succ_Low/Nitrate_High"
  [
  set output_file (word behaviorspace-run-number "_INDISIM_Paracoccus(V20_Metabolic)_Output_ScLw_NtHg_" ".txt") ; Outputfile name with .txt extension and Behaviorspace numering
  ]
  if Experiment = "Succ_High/Nitrate_Low"
  [
  set output_file (word behaviorspace-run-number "_INDISIM_Paracoccus(V20_Metabolic)_Output_ScHg_NtLw_" ".txt") ; Outputfile name with .txt extension and Behaviorspace numering
  ]
  carefully
  [file-delete output_file] [ ]
  file-open output_file
  file-type "Time_[h] "                                                  ; Simulation time labed in outputfile unit hours
  file-type "Succinate_[mM] "                                            ; Succinate concentration labed in outputfile unit milimolar
  file-type "NH4+_[mM] "                                                 ; Amonium concentration labed in outputfile unit milimolar
  file-type "O2_[mg/l] "                                                 ; Oxygen concentration labed in outputfile unit mg/ml
  file-type "NO3-_[mM] "                                                 ; Nitrate concentration labed in outputfile unit milimolar
  file-type "NO2-_[mM] "                                                 ; Nitrite concentration labed in outputfile unit milimolar
  file-type "NO_[mM] "                                                   ; Nitric Oxide concentration labed in outputfile unit milimolar
  if Experiment = "Succ_Low/Nitrate_High" [file-type "N2O_[uM] "]        ; Dinitrogen concentration labed in outputfile unit micromolar
  if Experiment = "Succ_High/Nitrate_Low" [file-type "N2O_[mM] "]        ; Dinitrogen concentration labed in outputfile unit milimolar
  file-type "N2_[mM] "                                                   ; Nitrogen concentration labed in outputfile unit milimolar
  file-type "CO2_[mM] "                                                  ; Carbon dioxide concentration labed in outputfile unit milimolar
  file-type "Biomass_[mg/ml] "                                           ; Biomass concentration labed in outputfile unit miligrams / mililiter
  file-type "Individuals "                                               ; Individuals into bioreactor labed in outputfile
  file-type "d "                                                         ; Reactor dilution ratio labed in outputfile units (h^-1)
  file-type "Sc_In_[mmol] "                                              ; Inflow Succinate labed in outputfile units milimoles
  file-type "NH4+_In_[mmol] "                                            ; Inflow Amonium labed in outputfile units milimoles
  file-type "NO3-_In_[mmol] "                                            ; Inflow Nitrate labed in outputfile units milimoles
  file-type "Sc_Out_[mmol] "                                             ; Outflow Succinate labed in outputfile units milimoles
  file-type "NH4+_Out_[mmol] "                                           ; Outflow amonium labed in outputfile units milimoles
  file-type "NO3-_Out_[mmol] "                                           ; Outflow  nitrate labed in outputfile units milimoles
  file-type "NO2-_Out_[mmol] "                                           ; Outflow nitrite labed in outputfile units milimoles
  file-type "NO_Out_[mmol] "                                             ; Outflow Nitric Oxide labed in outputfile units milimoles
  if Experiment = "Succ_Low/Nitrate_High" [file-type "N2O_Out_[umol] "]  ; Outflow Nitrous Oxide labed in outputfile units micromoles
  if Experiment = "Succ_High/Nitrate_Low" [file-type "N2O_Out_[mmol] "]  ; Outflow Nitrous oxide labed in outputfile units milimoles
  file-type "N2_Out_[mmol] "                                             ; Outflow Nitrogen gas labed in outputfile units milimoles
  file-type "Ind_Out "                                                   ; Outflow Microorganims labed in outputfile
  file-type "HCO3_[mM] "                                                 ; Bicarbonate concentration labed in outputfile units milimolar
  file-type "HCO3_Out_[mmol] "                                           ; Outflow Bicarbonate labed in outputfile units milimoles
  file-type "CO2_Out_[mmol] "                                            ; Outflow Carbon dioxide labed in outputfile units milimoles
  file-print " "
end

; ____________________________ Proceeding to write values on output file __________________________________________________________________________

to write-outputfile
  setup-monitors
  file-type time_now                                            ; Outputfile Simulated time [h]
  file-type " "
  file-type gsuccinate                                          ; Outputfile Bioreactor Succinate concentration [mM]
  file-type " "
  file-type gamonium                                            ; Outputfile Bioreactor Amonium concentration [mM]
  file-type " "
  file-type goxygen * 32                                        ; Outputfile Bioreactor Oxygen concentration [mg/l]
  file-type " "
  file-type gnitrate                                            ; Outputfile Bioreactor Nitrate concentration [mM]
  file-type " "
  file-type gno2-                                               ; Outputfile Bioreactor Nitrite concentration [mM]
  file-type " "
  file-type gno                                                 ; Outputfile Bioreactor Nitric Oxide concentration [mM]
  file-type " "
  file-type gn2o                                                ; Outputfile Bioreactor Nitrous Oxide concentration [mM][uM]
  file-type " "
  file-type gn2                                                 ; Outputfile Bioreactor Nitrogen gas concentration [mM]
  file-type " "
  file-type gdioxide                                            ; Outputfile Bioreactor Carbon Dioxide concentration [mM]
  file-type " "
  file-type gbacteria                                           ; Outputfile Bioreactor Biomass concentration [mg/ml]
  file-type " "
  file-type count bacteria                                      ; Outputfile Bioreactor microorganism count [individuals]
  file-type " "
  file-type d                                                   ; Outputfile Bioreactor Dilution ratio [h^1]
  file-type " "
  file-type succinate-input                                     ; Outputfile Inflow Succinate quantity [mmol]
  file-type " "
  file-type amonium-input                                       ; Outputfile Inflow Amonioum quantity [mmol]
  file-type " "
  file-type nitrate-input                                       ; Outputfile Inflow Nitrate quantity [mmol]
  file-type " "
  file-type xsc                                                 ; Outputfile Outflow Succinate quantity [mmol]
  file-type " "
  file-type xam                                                 ; Outputfile Outflow Amonium quantity [mmol]
  file-type " "
  file-type xntr                                                ; Outputfile Outflow Nitrate quantity [mmol]
  file-type " "
  file-type xnr                                                 ; Outputfile Outflow Nitrite quantity [mmol]
  file-type " "
  file-type xmn                                                 ; Outputfile Outflow Nitric oxide quantity [mmol]
  file-type " "
  if Experiment = "Succ_Low/Nitrate_High"[file-type xdn * 1000] ; Outputfile Outflow Nitrous oxide quantity [umol]
  if Experiment = "Succ_High/Nitrate_Low"[file-type xdn]        ; Outputfile Outflow Nitrous oxide quantity [mmol]
  file-type " "
  file-type xn2                                                 ; Outputfile Outflow Nitrogen gas quantity [mmol]
  file-type " "
  file-type bacteriaout                                         ; Outputfile Outflow microrganism quantity [individuals]
  file-type " "
  file-type gbicarbonate                                        ; Outputfile Bioreactor Bicarbonate concentration [mM]
  file-type " "
  file-type xhco3                                               ; Outputfile Outflow bicarbonate quantity [mmol]
  file-type " "
  file-type xco2                                                ; Outputfile Outflow Carbon Dioxide quantity [mmol]
  file-type " "
  file-print " "
end

; ____________________________ General mass balance proceedings _____________________________________________________________________________

to setup-balance
  set ibacteria (sum [biomass] of bacteria)                                                ; Initial Biomass [mmol]
  set isuccinate (sum[succinate-medium]of patches)                                         ; Initial Succinate [mmol]
  set iamonium (sum [amonium-medium] of patches)                                           ; Initial Amonium [mmol]
  set ioxygen (sum [oxygen-medium] of patches)                                             ; Initial Oxygen [mmol]
  set initrate (sum [nitrate-medium] of patches)                                           ; Initial Nitrate [mmol]
  set initrite (sum [nitrite-medium] of patches)                                           ; Initial Nitrite [mmol]
  set imonoxide (sum [monoxide-medium] of patches)                                         ; Initial Monoxide [mmol]
  set idinitrogen (sum [dinitrogen-medium] of patches)                                     ; Initial Dinitrogen [mmol]
  set idioxide (sum [dioxide] of patches)                                                  ; Initial Carbon dioxide [mmol]
  set initrogen (sum [nitrogen] of patches)                                                ; Initial Nitrogen [mmol]
  set ibicarbonate (sum [bicarbonate] of patches)                                          ; Initial Bicarbonate [mmol]
end

to reactor_balance
  set fbacteria (gbacteria * 1000 * world / 75)                                            ; Final Biomass [mmol]
  set fsuccinate (gsuccinate * world)                                                      ; Final Succinate [mmol]
  set famonium (gamonium * world)                                                          ; Final Amonium [mmol]
  set foxygen (goxygen * world)                                                            ; Final Oxygen [mmol]
  set fnitrate (gnitrate * world)                                                          ; Final Nitrate [mmol]
  set fnitrite (gno2- * world)                                                             ; Final Nitrite [mmol]
  set fmonoxide (gno * world)                                                              ; Final Monoxide [mmol]
  if Experiment = "Succ_Low/Nitrate_High"[set fdinitrogen ((gn2o * world) / 1000)]         ; Final Dinitrogen [mmol]
  if Experiment = "Succ_High/Nitrate_Low"[set fdinitrogen (gn2o * world)]                  ; FInal Dinitrogen [mmol]
  set fdioxide (gdioxide * world)                                                          ; Final Carbon dioxide [mmol]
  set fnitrogen (gn2 * world)                                                              ; Final Nitrogen [mmol]
  set fbicarbonate (gbicarbonate * world)                                                  ; Final Bicarbonate [mmol]
end

to inflow_balance
  set insuccinate (insuccinate + succinate-input)                                          ; Inflow Succinate [mmol]
  set inamonium (inamonium + amonium-input)                                                ; Inflow Amonium [mmol]
  set innitrate (innitrate + nitrate-input)                                                ; Inflow Nitrate [mmol]
end

to outflow_balance
  set outsuccinate (outsuccinate + xsc)                                                    ; OutFlow Succinate [mmol]
  set outamonium (outamonium + xam)                                                        ; OutFlow Amonium [mmol]
  set outoxygen (outoxygen + xox)                                                          ; OutFlow Oxygen [mmol]
  set outnitrate (outnitrate + xntr)                                                       ; Outflow Nitrtate [mmol]
  set outnitrite (outnitrite + xnr)                                                        ; Outflow Nitrite [mmol]
  set outmonoxide (outmonoxide + xmn)                                                      ; Outflow Monoxide [mmol]
  set outdinitrogen (outdinitrogen + xdn)                                                  ; Outflow N2O [mmol]
  set outnitrogen (outnitrogen + xn2)                                                      ; Outflow N2 [mmol]
  set outdioxide (outdioxide + xco2)                                                       ; Outflow CO2 [mmol]
  set outbicarbonate (outbicarbonate + xhco3)                                              ; outflow HCO3 [mmol]
  set outbacteria (outbacteria + xbacteria)                                                ; OutFlow Baacteria [mmol]
end

to general_mass_balance
  set icbacteria (ibacteria * 3 * 12)                                                      ; Initial C-Mic [mg]
  set inbacteria (ibacteria * 0.75 * 14)                                                   ; Initial N-Mic [mg]
  set fcbacteria (fbacteria * 3 * 12)                                                      ; Final C-Mic [mg]
  set fnbacteria (fbacteria * 0.75 * 14)                                                   ; Final N-Mic [mg]
  set outcbacteria (outbacteria * 3 * 12)                                                  ; OutFlow C-Mic [mg]
  set outnbacteria (outbacteria * 0.75 * 14)                                               ; OutFlow N-Mic [mg]

  set c-bacteria (fcbacteria - icbacteria) - (0 - outcbacteria)                            ; Microorganism Carbon balance
  set n-bacteria (fnbacteria - inbacteria) - (0 - outnbacteria)                            ; Microorganims Nitrogen balance
  set c-succinate ((fsuccinate - isuccinate) - (insuccinate - outsuccinate)) * 4 * 12      ; Succinate carbon balance
  set n-amonium ((famonium - iamonium) - (inamonium - outamonium)) * 1 * 14                ; Amonium nitrogen balance
  set n-nitrate ((fnitrate - initrate) - (innitrate - outnitrate)) * 1 * 14                ; Nitrate nitrogen balance
  set n-nitrite ((fnitrite - initrite) - (0 - outnitrite)) * 1 * 14                        ; Nitrite nitrogen balance
  set n-monoxide ((fmonoxide - imonoxide) - (0 - outmonoxide)) * 1 * 14                    ; Nitric oxide nitrogen balance
  set n-dinitrogen ((fdinitrogen - idinitrogen) - (0 - outdinitrogen)) * 2 * 14            ; Nitrous oxide nitrogen balance
  set n-nitrogen ((fnitrogen - initrogen) - (0 - outnitrogen)) * 2 * 14                    ; Nitrogen gas nitrogen balance
  set c-co2 ((fdioxide - idioxide) - (0 - outdioxide)) * 1 * 12                            ; Carbon dixoide carbon balance
  set c-hco3 ((fbicarbonate - ibicarbonate) - (0 - outbicarbonate)) * 1 * 12               ; Bicarbonate carbon balance

  set n-obtained abs (n-nitrite + n-monoxide + n-dinitrogen + n-nitrogen + n-bacteria)     ; Total nitrogen obtained
  set n-delivered abs (n-amonium + n-nitrate)                                              ; Total nitrogen delivered
  set c-obtained abs (c-co2 + c-hco3 + c-bacteria)                                         ; Total carbon obtained
  set c-delivered abs (c-succinate)                                                        ; Total carbon delivered

  set %_e_c abs ((c-delivered - c-obtained) / c-delivered ) * 100                          ; Carbon general mass balance porcentual error
  set %_e_n abs ((n-delivered - n-obtained) / n-delivered ) * 100                          ; Nitrogen general mass balance porcentual error
  set yc/c abs (c-bacteria / c-succinate)                                                  ; Population Yield growth
end

; ____________________________ Run Proceeding to Virtual Bioreactor __________________________________________________________________________

to go
  tick                                                                 ; Start tick counter
  set Araujo ticks
  ifelse Araujo = 1 [reset-timer] [ ]
  stir                                                                 ; Observer procedure to stablish quantities for outflow in batch and continuos culture.
  outflow                                                              ; Observer and patch procedure to make outflow from bioreactor in continuos culture with or without culture medium homogenization
  inflow                                                               ; Observer procedure to simulate input nutrients to bioreactor according to dilution ratio with or without culture medium homogenization
  maintenance-requirements                                             ; Observer procedure to calculate maintenance requirements for aerobic and anaerobic phases.

  ask bacteria
  [
    uptake                                                             ; Agent procedure, each time step the bacteria establish their uptake capacities of all nutrients
    ifelse oxygen-medium >= abs random-normal NOX (DST * NOX)          ; Agent procedure, according to oxygen local concentration runs different metabolic pathways
    [mant-aerobic][mant-anoxic1]
    metabolism_end                                                     ; Agent procedure, after cellular maintenance and biomass synthesis the uptaked nutrient quantities are updated
    bipartition                                                        ; Agent procedure, after execute metabolic pathways if the biomass reached the treshold valeu microorganism reproduce by bipartition
  ]

  ask bacteria [ move ]                                                ; Agent procedure, effect produced by the bioreactor agitation

  do-plotting                                                          ; Observer procedure, to setup graphical outputs
  if Output_file? = true
  [
;    if
;    ;time_now = 3 or
;    ;time_now = 4 or
;    time_now = 6 or
;    ;time_now = 7 or
;    time_now = 24 or
;    time_now = 24.5 or
;    time_now = 27 or
;    ;time_now = 28 or
;    ;time_now = 30 or
;    ;time_now = 47 or
;    ;time_now = 48 or
;    time_now = 49 or
;    ;time_now = 50 or
;    ;time_now = 51 or
;    time_now = 52 or
;    ;time_now = 53 or
;    time_now = 55 or
;    ;time_now = 71 or
;    time_now = 72 or
;    ;time_now = 74 or
;    time_now = 74.5 or
;    ;time_now = 75 or
;    ;time_now = 77 or
;    time_now = 78.5 or
;    ;time_now = 79 or
;    ;time_now = 95 or
;    ;time_now = 96 or
;    time_now = 96.5 or
;    ;time_now = 98 or
;    time_now = 99 or
;    time_now = 102 or
;    ;time_now = 119
;    time_now = 119.5
;    ;time_now = 120
;    [
      write-outputfile
      ; ]
  ]                            ; Observer procedure, write-out the all simulated data to output file.

  general_mass_balance

  if time_now >= Simulation_Time [file-close set pablo timer stop]                     ; Stop simulation if time is over and close output-file
  if (sum [succinate-medium] of patches / world) < 0 [file-close set pablo timer stop] ; Stop simulation if the succinate global concentration is lower to zero and close output-file
  if (sum [amonium-medium] of patches / world) < 0 [file-close set pablo timer stop]   ; Stop simulation if the amonium global concentration is lower to zero and close output-file
  if (sum [oxygen-medium] of patches / world) < 0 [file-close set pablo timer stop]    ; Stop simulation if the oxygen global concentration is lower to zero and close output-file
  if (sum [nitrate-medium] of patches / world) < 0 [file-close set pablo timer stop]   ; Stop simulation if the nitrate global concentration is lower to zero and close output-file
end

; ____________________________ Proceeding to simulate bioreactor agitation over the culture medium ____________________________________________________

to stir
  set succinatemedium (sum [succinate-medium] of patches)   ; Total Succinate in culture medium [mmol]
  set amoniummedium (sum [amonium-medium] of patches)       ; Total Amonium in culture medium [mmol]
  set oxygenmedium (sum [oxygen-medium] of patches)         ; Total Oxygen in culture medium [mmol]
  set nitratemedium (sum [nitrate-medium] of patches)       ; Total Nitrate in culture medium [mmol]
  set nitritemedium (sum [nitrite-medium] of patches)       ; Total Nitrite in culture medium [mmol]
  set monoxidemedium (sum [monoxide-medium] of patches)     ; Total Nitric oxide in culture medium [mmol]
  set dinitrogenmedium (sum [dinitrogen-medium] of patches) ; Total Nitrous oxide in culture medium [mmol]
  set nitrogenmedium (sum [nitrogen] of patches)            ; Total nitrogen gas in culture medium [mmol]
  set dioxidemedium (sum [dioxide] of patches)              ; Total carbon dioxide in culture medium [mmol]
  set bicarbonatemedium (sum [bicarbonate] of patches)      ; Total bicarbonate in culture medium [mmol]

  ifelse time_now >= Time_Shutdown_O2                       ; if simulated time is lower than time_shutdown_O2
  [set d abs random-normal (di) (DST * di)]                 ; Bioreactor works in continuos culture according to dilution ratio
  [
    set d 0                                                 ; the bioreactor works in batch conditions
    if oxygenmedium > 0.2360 * world
    [set oxygenmedium 0.2360 * world]                       ; and the oxygen keep saturated conditions
  ]
  set xsc d * succinatemedium * steptime                    ; succinate outflow according to dilution ratio [mmol]
  set xam d * amoniummedium * steptime                      ; amonium outflow according to dilution ratio [mmol]
  set xox d * oxygenmedium * steptime                       ; oxygen outflow according to dilution ration [mmol]
  set xntr d * nitratemedium * steptime                     ; nitrate outflow according to dilution ration [mmol]
  set xnr d * nitritemedium * steptime                      ; nitrite outflow according to dilution ration [mmol]
  set xmn d * monoxidemedium * steptime                     ; nitric oxide outflow according to dilution ration [mmol]
  set xdn d * dinitrogenmedium * steptime                   ; nitrous oxide outflow according to dilution ration [mmol]
  set xn2 d * nitrogenmedium * steptime                     ; nitrogen gas outflow according to dilution ration [mmol]
  set xco2 d * dioxidemedium * steptime                     ; carbon dioxide outflow according to dilution ration [mmol]
  set xhco3 d * bicarbonatemedium * steptime                ; bicarbonate outflow according to dilution ration [mmol]
  if xmn >= (3.27 * world) [set xmn (3.27 * world)]         ; if nitric oxide quantity is higher than maximun saturated conditions outflow only the saturated conditions
  if xdn >= (58.27 * world) [set xdn (58.27 * world)]       ; if nitrous oxide quantity is higher than maximun saturated conditions outflow only the saturated conditions
  if xn2 >= (104.91 * world) [set xn2 (104.91 * world)]     ; if nitrogen gas quantity is higher than maximun saturated conditions outflow only the saturated conditions
  if xco2 >= (8009.05 * world) [set xco2 (8009.05 * world)] ; if carbon dioxide quantity is higher than maximun saturated conditions outflow only the saturated conditions

  let bactout (sum [biomass] of bacteria)                   ; Total biomass in culture medium [mmol]
  let xbact (d * bactout * steptime)                        ; biomass outflow according to dilution ratio [mmol]
  let prom (count bacteria / bactout)                       ; average individual per biomass in outflow [individual ml /mg]
  set bacteriaout round (xbact * prom)                      ; Microorganism quantity to outflow [individuals]
  let monp (bactout / count bacteria)                       ; average biomass per individual in outflow [mg / ml individual]
  set xbacteria (monp * bacteriaout)                        ; Microorganism biomass concentration to outflow [mmol]

  outflow_balance
end

; ____________________________ Proceeding to simulate reactor OutFlow ________________________________________________________________________________________

to outflow
  set q random 2
  ifelse q = 0 [
   ask patches [
    set succinate-medium (succinatemedium - xsc) / world      ; The succinate outflow quantity is taken from global quantity and then homogenization occurs.
    set amonium-medium (amoniummedium - xam) / world          ; The amonium outflow quantity is taken from global quantity and then homogenization occurs.
    set oxygen-medium (oxygenmedium) / world                  ; Agitation and homogenization of oxygen
    set nitrate-medium (nitratemedium - xntr) / world         ; The nitrate outflow quantity is taken from global quantity and then homogenization occurs.
    set nitrite-medium (nitritemedium - xnr) / world          ; The nitrite outflow quantity is taken from global quantity and then homogenization occurs.
    set monoxide-medium (monoxidemedium - xmn) / world        ; The nitric oxide outflow quantity is taken from global quantity and then homogenization occurs.
    set dinitrogen-medium (dinitrogenmedium - xdn) / world    ; The nitrous oxide outflow quantity is taken from global quantity and then homogenization occurs.
    set nitrogen (nitrogenmedium - xn2) / world               ; The nitrogen gas outflow quantity is taken from global quantity and then homogenization occurs.
    set dioxide (dioxidemedium - xco2 ) / world               ; The carbon dioxide outflow quantity is taken from global quantity and then homogenization occurs.
    set bicarbonate (bicarbonatemedium - xhco3) / world       ; The bicarbonate outflow quantity is taken from global quantity and then homogenization occurs.
    set pcolor scale-color blue succinate-medium 0 Succinate
    ]
  ]
  [
    ask patches [
    set succinate-medium succinate-medium - (xsc / world)     ; The succinate outflow concentration is taken from local quantity without homogenization.
    set amonium-medium amonium-medium - (xam / world)         ; The amonium outflow concentration is taken from local quantity without homogenization.
    set oxygen-medium (oxygenmedium) / world                  ; Agitation and homogenization of oxygen
    set nitrate-medium nitrate-medium - (xntr / world)        ; The nitrate outflow concentration is taken from local quantity without homogenization.
    set nitrite-medium nitrite-medium - (xnr / world)         ; The nitrite outflow concentration is taken from local quantity without homogenization.
    set monoxide-medium monoxide-medium - (xmn / world)       ; The nitric oxide outflow concentration is taken from local quantity without homogenization.
    set dinitrogen-medium dinitrogen-medium - (xdn / world)   ; The nitrous oxide outflow concentration is taken from local quantity without homogenization.
    set nitrogen nitrogen - (xn2 / world)                     ; The nitrogen gas outflow concentration is taken from local quantity without homogenization.
    set dioxide dioxide - (xco2 / world)                      ; The carbon dioxide outflow concentration is taken from local quantity without homogenization.
    set bicarbonate bicarbonate - (xhco3 / world)             ; The bicarbonate outflow concentration is taken from local quantity without homogenization.
    set pcolor scale-color blue succinate-medium 0 Succinate
    ]
  ]
  ask n-of bacteriaout bacteria [ die ]                       ; Choose random bacteria and outflow accord to reactor dilution ratio
end

; __________________________________ Proceeding to simulate reactor Inflow ____________________________________________________________________________________

to inflow
  set succinate-input d * world * Succinate * steptime                        ; Succinate inflow to continuos culture according to the slider labed succinate [mmol]
  set amonium-input d * world * Amonium * steptime                            ; Amonium inflow to continuos culture according to the slider labed amonium [mmol]
  set nitrate-input d * world * Nitrate * steptime                            ; Nitrate inflow to continuos culture according to the slider labed nitrate [mmol]

  set succinatemedium (sum [succinate-medium] of patches) + (succinate-input) ; Total Succinate in culture medium after inflow [mmol]
  set amoniummedium (sum [amonium-medium] of patches) + (amonium-input)       ; Total Amonium in culture medium after inflow [mmol]
  set nitratemedium (sum [nitrate-medium] of patches) + (nitrate-input)       ; Total Nitrate in culture medium after inflow [mmol]
  if time_now <= Time_Shutdown_O2 [set oxygenmedium 0.2360 * world]

  inflow_balance

  ifelse q = 0
  [ ask patches
   [ set succinate-medium succinatemedium / world                                ; The succinate inflow quantity is added to global quantity and then homogenization occurs.
     set amonium-medium amoniummedium / world                                    ; The amonium inflow quantity is added to global quantity and then homogenization occurs.
     set oxygen-medium oxygenmedium / world                                      ; The oxygen inflow quantity is added to global quantity and then homogenization occurs.
     set nitrate-medium nitratemedium / world                                    ; The nitrate inflow quantity is added to global quantity and then homogenization occurs.
     set pcolor scale-color blue succinate-medium 0 Succinate
   ]
  ]
  [ ask patches
   [ set succinate-medium succinate-medium + (succinate-input / world)           ; The succinate inflow concentration is added to local quantity without homogenization.
     set amonium-medium amonium-medium + (amonium-input / world)                 ; The amonium inflow concentration is added to local quantity without homogenization.
     set oxygen-medium oxygenmedium / world
     set nitrate-medium nitrate-medium + (nitrate-input / world)                 ; The nitrate inflow concentration is added to local quantity without homogenization.
     set pcolor scale-color blue succinate-medium 0 Succinate
    ]
  ]
end

; ____________________________ Maintenance Requirements for aerobic and anaerobic phases __________________________________________________________________________

to maintenance-requirements

ifelse time_now <= Time_Shutdown_O2
  [                                                               ; 1/14 (C4H4O4)2- + 1/4 O2 -> 1/7 CO2 + 1/7 HCO3- + 1/14 H2O
    set scm (energy_maintenance_a * steptime  * 36.033 / 48.044)  ; [mol succinate / molBiomass]
    set oxm (scm * 0.25 / 0.0714)                                 ; [mol oxygen / molBiomass ]
  ]
  [                                                               ; 1/14 (C4H4O4)2- + 1/2 NO3- -> 1/7 CO2 + 1/7 HCO3- + 1/2 NO2- + 1/14 H2O
    set scm (energy_maintenance_x * steptime * 36.033 / 48.044)   ; [mol succinate / molBiomass ]
    set ntrm (scm * 0.50 / 0.0714)                                ; [mol nitrate / molBiomass ]
  ]
end

; ____________________________ Uptake proceeding according the core model INDISM __________________________________________________________________________

to uptake
  let uptsc (abs (random-normal (uSc) (DST * uSc)) * biomass * steptime)                ; [mmo] succinate by biomass uptake accord to INDISIM
  let uptam (abs (random-normal (uam) (DST * uam)) * biomass * steptime)                ; [mmol] amonium by biomass uptake accord to INDISIM
  let uptox (abs (random-normal (uox) (DST * uox)) * biomass * steptime)                ; [mmol] oxygen by biomass uptake accord to INDISIM
  ifelse time_now <= Time_Shutdown_O2 [set untri uNO3-a][set untri uNO3-x]              ; The microorganism takes different uptake coefficient for aerobic and anaerobic phase.
  let uptntr (abs (random-normal (untri) (DST * untri)) * biomass * steptime)           ; [mmol] nitrate by biomass uptake accord to INDISIM
  let uptnr (abs (random-normal (uNO2-) (DST * uNO2-)) * biomass * steptime)            ; [mmol] nitrite by biomass uptake accord to INDISIM
  let uptmn (abs (random-normal (uNO) (DST * uNO)) * biomass * steptime)                ; [mmol] nitric oxide by biomass uptake accord to INDISIM
  let uptdn (abs (random-normal (uN2O) (DST * uN2O)) * biomass * steptime)              ; [mmol] nitrous oxide by biomass uptake accord to INDISIM

  let sc-available (nsc * succinate-medium * k_avail)                                   ; INDISIM lineal model to determine succinate availability in culture medium [mmol]
  let am-available (nam * amonium-medium * k_avail )                                    ; INDISIM lineal model to determine amonium availability in culture medium [mmol]
  let ox-available (nx * oxygen-medium * k_avail )                                      ; INDISIM lineal model to determine oxygen availability in culture medium [mmol]
  let ntr-available (nntr * nitrate-medium * k_avail )                                  ; INDISIM lineal model to determine nitrate availability in culture medium [mmol]
  let nr-available (nnr * nitrite-medium * k_avail )                                    ; INDISIM lineal model to determine nitrite availability in culture medium [mmol]
  let mn-available (nmn * monoxide-medium * k_avail )                                   ; INDISIM lineal model to determine nitric oxide availability in culture medium [mmol]
  let dn-available (ndn * dinitrogen-medium * k_avail )                                 ; INDISIM lineal model to determine nitrous oxide availability in culture medium [mmol]

  ifelse sc-available <= uptsc [set sc-useful sc-available] [set sc-useful uptsc]       ; For succinate comparation between uptake by biomass and availability and takes the lowest value.
  ifelse am-available <= uptam [set am-useful am-available] [set am-useful uptam]       ; For amonium comparation between uptake by biomass and availability and takes the lowest value.
  ifelse ox-available <= uptox [set ox-useful ox-available] [set ox-useful uptox]       ; For oxygen comparation between uptake by biomass and availability and takes the lowest value.
  ifelse ntr-available <= uptntr [set ntr-useful ntr-available] [set ntr-useful uptntr] ; For nitrate comparation between uptake by biomass and availability and takes the lowest value.
  ifelse nr-available <= uptnr [set nr-useful nr-available] [set nr-useful uptnr]       ; For nitrite comparation between uptake by biomass and availability and takes the lowest value.
  ifelse mn-available <= uptmn [set mn-useful mn-available] [set mn-useful uptmn]       ; For nitric oxide comparation between uptake by biomass and availability and takes the lowest value.
  ifelse dn-available <= uptdn [set dn-useful dn-available] [set dn-useful uptdn]       ; For nitrous oxide comparation between uptake by biomass and availability and takes the lowest value.

  set succinate-medium (succinate-medium - sc-useful)                                   ; Update local quantity of succinate
  set amonium-medium (amonium-medium - am-useful)                                       ; Update local quantity of amonium
  set oxygen-medium (oxygen-medium - ox-useful)                                         ; Update local quantity of oxygen
  set nitrate-medium (nitrate-medium - ntr-useful)                                      ; Update local quantity of nitrate
  set nitrite-medium (nitrite-medium - nr-useful)                                       ; Update local quantity of nitrite
  set monoxide-medium (monoxide-medium - mn-useful)                                     ; Update local quantity of nitric oxide
  set dinitrogen-medium (dinitrogen-medium - dn-useful)                                 ; Update local quantity of nitrous oxide

end

; ____________________________ Aerobic phase proceeding according to TEEM2 __________________________________________________________________________
; ____________________________ Aerobic Maintenance __________________________________________________________________________________________________

to mant-aerobic                                                          ; 1/14 (C4H4O4)2- + 1/4 O2 -> 1/7 CO2 + 1/7 HCO3- + 1/14 H2O
  let sc-mant (scm * biomass)                                            ; Succinate celullar maintenance requirements by biomass [mmol]
  let ox-mant (oxm * biomass)                                            ; Oxygen cellular maintenance requirements by biomass [mmol]

  let y min (list sc-mant sc-useful)                                     ; takes the minimum value between maintenance requirements and uptake quantity for Succinate [mmol]
  let z min (list ox-mant ox-useful)                                     ; takes the minimum value between maintenance requirements and uptake quantity for Oxygen [mmol]

  let y1 (y / 0.0714)                                                    ; succinate quantity by stoichometric coefficient
  let z1 (z / 0.25)                                                      ; oxygen quantity by stoichiometric coefficient

  let w1 min (list y1 z1)                                                ; limiting nutrient for aerobic maintenance

  let ndioxide (0.1428 * w1)                                             ; Carbon dioxide generation by cellular maintenance [mmol]
  let nbicarbonate (0.1428 * w1)                                         ; Bicarbonate generation by cellular maintenance [mmol]
  set dioxide (dioxide + ndioxide)                                       ; Carbon dioxide local quantity update
  set bicarbonate (bicarbonate + nbicarbonate)                           ; Bicarbonate local quantity update

  set sc-useful (sc-useful - 0.0714 * w1)                                ; Update of Succinate uptaked  [mmol]
  set ox-useful (ox-useful - 0.25 * w1)                                  ; Update of Oxygen uptaked [mmol]
  set m_aero m_aero + 1                                                  ; counter to maintenance reaction on aerobic phase

  if (sc-useful > 0) and (am-useful > 0) and (ox-useful > 0) [aerobic1]  ; if uptaken updated quantities are higher than zero the microorganism could execute first aerobic parthway
  if (sc-useful > 0) and (am-useful > 0) and (ntr-useful > 0) [aerobic2] ; if uptaken updated quantities are higher than zero the microorganism could execute second aerobic parthway
end

; ______________________________ Aerobic Sinthesis ______________________________________________________________________________________________________

to aerobic1 ; 0.0714 (C4H4O4)2- + 0.0431 NH4+ + 0.0740 O2 ->  0.0575 C3H5.4N0.75O1.45 + 0.0136 CO2 + 0.0998 HCO3- + 0.0240 H2O adjusted by TEEM2 (McCarty, 2007)
  let a (sc-useful / 0.0714)                                             ; uptaken succinate updated divided by its stoichiometric coefficient
  let b (am-useful / 0.0431)                                             ; uptaken amonium updated divided by its stoichiometric coefficient
  let c (ox-useful / 0.0740)                                             ; uptaken oxygen updated divided by its stoichiometric coefficient

  let x1 min (list a b c)                                                ; limiting nutrient for pathway 1 in aerobic phase

  let nbiomass 0.0575 * x1                                               ; Biomass generation by aerobic pathway 1 [mmol]
  let ndioxide 0.0136 * x1                                               ; Carbon dioxide generation by aerobic pathway 1 [mmol]
  let nbicarbonate 0.0998 * x1                                           ; Bicarbonate generation by aerobic pathway 1 [mmol]
  set biomass (biomass + nbiomass)                                       ; Individual biomass update
  set dioxide (dioxide + ndioxide)                                       ; Carbon dioxide local quantity update
  set bicarbonate (bicarbonate + nbicarbonate)                           ; Bicarbonate local quantity update

  set sc-useful (sc-useful - 0.0714 * x1)                                ; update electron donor bacterium quantity
  set am-useful (am-useful - 0.0431 * x1)                                ; update N-source bacterium quantity
  set ox-useful (ox-useful - 0.0740 * x1)                                ; update electron aceptor bacterium quantity
  set s_aero_1 s_aero_1 + 1                                              ; counter to pathway 1 on aerobic phase

  if (sc-useful > 0) and (am-useful > 0) and (ntr-useful > 0) [aerobic2] ; if uptaken updated quantities are higher than zero the microorganism could execute second aerobic parthway
end

to aerobic2 ; 0.0714 (C4H4O4)2- + 0.0429 NH4+ + 0.0374 NO3- + 0.0748 H+ + 0.0132 H2O ->  0.0572 C3H5.4N0.75O1.45 + 0.0141 CO2 + 0.0999 HCO3- + 0.0374 NH4+ adjusted by TEEM2 (McCarty, 2007)
  let a (sc-useful / 0.0714)                     ; uptaken succinate updated divided by its stoichiometric coefficient
  let b (am-useful / 0.0429)                     ; uptaken amonium updated divided by its stoichiometric coefficient
  let c (ntr-useful / 0.0374)                    ; uptaken nitrate updated divided by its stoichiometric coefficient

  let x2 min (list a b c)                        ; limiting nutrient for pathway 2 in aerobic phase

  let nbiomass 0.0572 * x2                       ; Biomass generation by aerobic pathway 2 [mmol]
  let ndioxide 0.0141 * x2                       ; Carbon dioxide generation by aerobic pathway 2 [mmol]
  let namonium 0.0374 * x2                       ; Amonium generation by aerobic pathway 2 [mmol]
  let nbicarbonate 0.0999 * x2                   ; Bicarbonate generation by aerobic pathway 1 [mmol]
  set biomass (biomass + nbiomass)               ; Individual biomass update
  set dioxide (dioxide + ndioxide)               ; Carbon dioxide local quantity update
  set bicarbonate (bicarbonate + nbicarbonate)   ; Bicarbonate local quantity update
  set amonium-medium (amonium-medium + namonium) ; Amonium uptake quantity update

  set sc-useful (sc-useful - 0.0714 * x2)        ; update electron donor bacterium quantity
  set am-useful (am-useful - 0.0429 * x2)        ; update N-source bacterium quantity
  set ntr-useful (ntr-useful - 0.0374 * x2)      ; update electron aceptor bacterium quantity
  set s_aero_2 s_aero_2 + 1                      ; counter to pathway 2 on aerobic phase
end

; ____________________________ Anaerobic phase proceeding ________________________________________________________________________________________________________
; _____________________ Anoxics reactions are execute according to Reduction Order _______________________________________________________________________________
; _____________________________Cellular maintenance to anoxic reaction 1 _________________________________________________________________________________________

to mant-anoxic1                                  ; 1/14 (C4H4O4)2- + 1/2 NO3- -> 1/7 CO2 + 1/7 HCO3- + 1/2 NO2- + 1/14 H2O

  let sc-mant (scm * biomass)                    ; Succinate celullar maintenance requirements by biomass [mmol]
  let ntr-mant (ntrm * biomass)                  ; Nitrate celullar maintenance requirements by biomass [mmol]

  let y min (list sc-mant sc-useful)             ; takes the minimum value between maintenance requirements and uptake quantity for Succinate [mmol]
  let z min (list ntr-mant ntr-useful)           ; takes the minimum value between maintenance requirements and uptake quantity for Nitrate [mmol]

  let y1 (y / 0.0714)                            ; Succinate quantity by stoichometric coefficient
  let z1 (z / 0.50)                              ; Nitrate quantity by stoichometric coefficient
  let w1 min (list y1 z1)                        ; limiting nutrient for first anaerobic maintenance

  let ndioxide 0.1428 * w1                       ; Carbon dioxide generation by cellular maintenance [mmol]
  let nbicarbonate 0.1428 * w1                   ; Bicarbonate generation by cellular maintenance [mmol]
  let nnitrite 0.50 * w1                         ; Nitrite generation by cellular maintenance [mmol]
  set dioxide (dioxide + ndioxide)               ; Carbon dioxide local quantity update
  set bicarbonate (bicarbonate + nbicarbonate)   ; Bicarbonate local quantity update

  if ntr-mant > ntr-useful [set sc-mant2 sc-mant - 0.0714 * w1 ] ; Maintenance control

  set nr-useful (nr-useful + nnitrite)          ; Uptaken nitrite updated
  set sc-useful (sc-useful - 0.0714 * w1)       ; Update of Succinate uptaked  [mmol]
  set ntr-useful (ntr-useful - 0.50 * w1)       ; Update of Nitrate uptaked  [mmol]

  set m_anox_1 m_anox_1 + 1                     ; counter to first maintenance reaction on anaerobic phase

  if sc-useful <= 0 [stop]                      ; if the succinate uptaken is lower than zero stop the microorganism metabolism until the next step time
  ifelse sc-mant2 > 0 [mant-anoxic2] [anoxic1]  ; if maintenance is fullfiled go to biomass synthesis procedures
end

; _____________________________Cellular maintenance to anoxic reaction 2 _________________________________________________________________________________________

to mant-anoxic2                                     ; 1/14 (C4H4O4)2- + NO2- -> 1/7 CO2 + 1/7 HCO3- + NO + 4/7 H2O

  let nr-mant2 (sc-mant2 * 1.0 / 0.0714)            ; nitrite maintenance requirements from succinate maintenance requirements

  let y min (list sc-mant2 sc-useful)               ; takes the minimum value between maintenance requirements and remaining uptaken quantity for Succinate [mmol]
  let z min (list nr-mant2 nr-useful)               ; takes the minimum value between maintenance requirements and uptake quantity for nitrite [mmol]

  let y1 (y / 0.0714)                               ; Succinate quantity by stoichometric coefficient
  let z1 (z / 1.0)                                  ; Nitrite quantity by stoichometric coefficient
  let w2 min (list y1 z1)                           ; limiting nutrient for second anaerobic maintenance

  let ndioxide 0.1428 * w2                          ; Carbon dioxide generation by cellular maintenance [mmol]
  let nbicarbonate 0.1428 * w2                      ; Bicarbonate generation by cellular maintenance [mmol]
  let nmonoxide 1.0 * w2                            ; Nitric oxide generation by cellular maintenance [mmol]
  set dioxide (dioxide + ndioxide)                  ; Carbon dioxide local quantity update
  set bicarbonate (bicarbonate + nbicarbonate)      ; Bicarbonate local quantity update
  set monoxide-medium (monoxide-medium + nmonoxide) ; Nitric oxide generation release to culture medium

  if  nr-mant2 > nr-useful [set sc-mant3 sc-mant2 - 0.0714 * w2 ] ; Maintenance control

  set sc-useful (sc-useful - w2 * 0.0714)           ; Update of Succinate uptaken  [mmol]
  set nr-useful (nr-useful - w2 * 1)                ; Update of Nitrite uptaken  [mmol]

  set m_anox_2 m_anox_2 + 1                         ; counter to second maintenance reaction on anaerobic phase

  if sc-useful <= 0 [stop]                          ; if the succinate uptaken is lower than zero stop the microorganism metabolism until the next step time
  ifelse sc-mant3 > 0 [mant-anoxic3] [anoxic2]      ; if maintenance is fullfiled go to biomass synthesis procedures
end

; _____________________________Cellular maintenance to anoxic reaction 3 _________________________________________________________________________________________

to mant-anoxic3                                           ; 1/14 (C4H4O4)2- + NO -> 1/7 CO2 + 1/7 HCO3- + 1/2 N2O + 1/14 H2O

  let mn-mant3 (sc-mant3 * 1.0 / 0.0714)                  ; nitric oxide maintenance requirements from succinate maintenance requirements

  let y min (list sc-mant3 sc-useful)                     ; takes the minimum value between maintenance requirements and remaining uptaken quantity for Succinate [mmol]
  let z min (list mn-mant3 mn-useful)                     ; takes the minimum value between maintenance requirements and uptake quantity for nitric oxide [mmol]

  let y1 (y / 0.0714)                                     ; Succinate quantity by stoichometric coefficient
  let z1 (z / 1.0)                                        ; Nitric oxide quantity by stoichometric coefficient
  let w3 min (list y1 z1)                                 ; limiting nutrient for third anaerobic maintenance

  let ndioxide 0.1428 * w3                                ; Carbon dioxide generation by cellular maintenance [mmol]
  let nbicarbonate 0.1428 * w3                            ; Bicarbonate generation by cellular maintenance [mmol]
  let ndinitrogen 0.5 * w3                                ; Nitrous oxide generation by cellular maintenance [mmol]
  set dioxide (dioxide + ndioxide)                        ; Carbon dioxide local quantity update
  set bicarbonate (bicarbonate + nbicarbonate)            ; Bicarbonate local quantity update
  set dinitrogen-medium (dinitrogen-medium + ndinitrogen) ; Nitrous oxide generation release to culture medium

  if mn-mant3 >= mn-useful [set sc-mant4 sc-mant3 - 0.0714 * w3 ] ; Maintenance control

  set sc-useful (sc-useful - w3 * 0.0714)                 ; Update of Succinate uptaken  [mmol]
  set mn-useful (mn-useful - w3 * 1)                      ; Update of Nitric oxide uptaken  [mmol]

  set m_anox_3 m_anox_3 + 1                               ; counter to third maintenance reaction on anaerobic phase

  if sc-useful <= 0 [stop]                                ; if the succinate uptaken is lower than zero stop the microorganism metabolism until the next step time
  ifelse sc-mant4 > 0 [mant-anoxic4] [anoxic3]            ; if maintenance is fullfiled go to biomass synthesis procedures
end

; _____________________________Cellular maintenance to anoxic reaction 4 _________________________________________________________________________________________

to mant-anoxic4                                ; 1/14 (C4H4O4)2- + 1/2 N2O -> 1/7 CO2 + 1/7 HCO3- + 1/2 N2 + 1/14 H2O

  let dn-mant (sc-mant4 * 0.5 / 0.0714)        ; nitrous oxide maintenance requirements from succinate maintenance requirements

  let y min (list sc-mant4 sc-useful)          ; takes the minimum value between maintenance requirements and remaining uptaken quantity for Succinate [mmol]
  let z min (list dn-mant dn-useful)           ; takes the minimum value between maintenance requirements and uptake quantity for nitrous oxide [mmol]

  let y1 (y / 0.0714)                          ; Succinate quantity by stoichometric coefficient
  let z1 (z / 0.50)                            ; Nitrous oxide quantity by stoichometric coefficient
  let w4 min (list y1 z1)                      ; limiting nutrient for fourth anaerobic maintenance

  let ndioxide 0.1428 * w4                     ; Carbon dioxide generation by cellular maintenance [mmol]
  let nbicarbonate 0.1428 * w4                 ; Bicarbonate generation by cellular maintenance [mmol]
  let nnitrogen 0.5 * w4                       ; Nitrogen gas generation by cellular maintenance [mmol]
  set dioxide (dioxide + ndioxide)             ; Carbon dioxide local quantity update
  set bicarbonate (bicarbonate + nbicarbonate) ; Bicarbonate local quantity update
  set nitrogen nitrogen + nnitrogen            ; Nitrogen gas local quantity update

  set sc-useful (sc-useful - w4 * 0.0714)      ; Update of Succinate uptaken  [mmol]
  set dn-useful (dn-useful - w4 * 0.5)         ; Update of Nitrous oxide uptaken  [mmol]

  set m_anox_4 m_anox_4 + 1                    ; counter to fourth maintenance reaction on anaerobic phase

  ifelse (sc-useful > 0) and (am-useful > 0) and (dn-useful > 0) [anoxic4][stop] ; if maintenance is fullfiled go to biomass synthesis procedures
end

; _____________________ Anoxics reactions are execute according to Reduction Order _______________________________________________________________________________
; _____________________________ Biomass Synthesis to anoxic reaction 1 ___________________________________________________________________________________________

to anoxic1 ; 0.0714 (C4H4O4)2- + 0.0214 NH4+ + 0.3250 NO3- ->  0.0286 C3H5.4N0.75O1.45 + 0.3250 NO2- + 0.0786 CO2 + 0.1214 HCO3- + 0.0479 H2O adjusted by TEEM2 (McCarty, 2007)

  let a (sc-useful / 0.0714)                                           ; uptaken succinate updated divided by its stoichiometric coefficient
  let b (am-useful / 0.0214)                                           ; uptaken amonium updated divided by its stoichiometric coefficient
  let c (ntr-useful / 0.3250)                                          ; uptaken nitrate updated divided by its stoichiometric coefficient

  let x1 min (list a b c)                                              ; limiting nutrient for enzimatic reaction 1 on pathway 3 in anaerobic phase

  let nbiomass 0.0286 * x1                                             ; Biomass generation for enzimatic reaction 1 on pathway 3 [mmol]
  let ndioxide 0.0786 * x1                                             ; Carbon dioxide generation for enzimatic reaction 1 on pathway 3 [mmol]
  let nnitrite 0.3250 * x1                                             ; Nitrite generation for enzimatic reaction 1 on pathway 3 [mmol]
  let nbicarbonate 0.1214 * x1                                         ; Bicarbonate generation for enzimatic reaction 1 on pathway 3 [mmol]
  set biomass (biomass + nbiomass)                                     ; Individual biomass update
  set dioxide (dioxide + ndioxide)                                     ; Carbon dioxide local quantity update
  set bicarbonate (bicarbonate + nbicarbonate)                         ; Bicarbonate local quantity update
  set nr-useful (nr-useful + nnitrite)                                 ; Update of nitrite uptaken

  set sc-useful (sc-useful - 0.0714 * x1)                              ; update electron donor bacterium quantity
  set am-useful (am-useful - 0.0214 * x1)                              ; update N-source bacterium quantity
  set ntr-useful (ntr-useful - 0.3250 * x1)                            ; update electron aceptor bacterium quantity
  set s_anox_1 s_anox_1 + 1                                            ; counter to first biomass synthesis reaction on anaerobic phase

  if (sc-useful > 0) and (am-useful > 0) and (nr-useful > 0) [anoxic2] ; if the succinate, amonium and nitrite quatities are enough go to enzimatic reaction 2
  if (sc-useful > 0) and (am-useful > 0) and (mn-useful > 0) [anoxic3] ; if the succinate, amonium and nitric oxide quatities are enough go to enzimatic reaction 3
  if (sc-useful > 0) and (am-useful > 0) and (dn-useful > 0) [anoxic4] ; if the succinate, amonium and nitrous oxide quatities are enough go to enzimatic reaction 4
end

; _____________________________ Biomass Synthesis to anoxic reaction 2 ___________________________________________________________________________________________

to anoxic2 ; 0.0714 (C4H4O4)2- + 0.0413 NH4+ + 0.3250 NO2- + 0.3250 H+ ->  0.0551 C3H5.4N0.75O1.45 + 0.3250 NO + 0.0189 CO2 + 0.1015 HCO3- + 0.1885 H2O adjusted by TEEM2 (McCarty, 2007)

  let a (sc-useful / 0.0714)                                           ; uptaken succinate updated divided by its stoichiometric coefficient
  let b (am-useful / 0.0413)                                           ; uptaken amonium updated divided by its stoichiometric coefficient
  let c (nr-useful / 0.3250)                                           ; uptaken nitrite updated divided by its stoichiometric coefficient

  let x2 min (list a b c)                                              ; limiting nutrient for enzimatic reaction 2 on pathway 3 in anaerobic phase

  let nbiomass 0.0551 * x2                                             ; Biomass generation for enzimatic reaction 2 on pathway 3 [mmol]
  let ndioxide 0.0189 * x2                                             ; Carbon dioxide generation for enzimatic reaction 2 on pathway 3 [mmol]
  let nmonoxide 0.3250 * x2                                            ; Nitric oxide generation for enzimatic reaction 2 on pathway 3 [mmol]
  let nbicarbonate 0.1015 * x2                                         ; Bicarbonate generation for enzimatic reaction 2 on pathway 3 [mmol]
  set biomass (biomass + nbiomass)                                     ; Individual biomass update
  set dioxide (dioxide + ndioxide)                                     ; Carbon dioxide local quantity update
  set bicarbonate (bicarbonate + nbicarbonate)                         ; Bicarbonate local quantity update
  set mn-useful (mn-useful + nmonoxide)                                ; Update of nitric oxide uptaken

  set sc-useful (sc-useful - 0.0714 * x2)                              ; update electron donor bacterium quantity
  set am-useful (am-useful - 0.0413 * x2)                              ; update N-source bacterium quantity
  set nr-useful (nr-useful - 0.3250 * x2)                              ; update electron aceptor bacterium quantity
  set s_anox_2 s_anox_2 + 1                                            ; counter to second biomass synthesis reaction on anaerobic phase

  if (sc-useful > 0) and (am-useful > 0) and (mn-useful > 0)[anoxic3]  ; if the succinate, amonium and nitric oxide quatities are enough go to enzimatic reaction 3
  if (sc-useful > 0) and (am-useful > 0) and (dn-useful > 0)[anoxic4]  ; if the succinate, amonium and nitrous oxide quatities are enough go to enzimatic reaction 4
end

; _____________________________ Biomass Synthesis to anoxic reaction 3 ___________________________________________________________________________________________

to anoxic3 ; 0.0714 (C4H4O4)2- + 0.0413 NH4+ + 0.3250 NO ->  0.0551 C3H5.4N0.75O1.45 + 0.1625 N2O + 0.0189 CO2 + 0.1015 HCO3- + 0.0260 H2O adjusted by TEEM2 (McCarty, 2007)

  let a (sc-useful / 0.0714)                                           ; uptaken succinate updated divided by its stoichiometric coefficient
  let b (am-useful / 0.0413)                                           ; uptaken amonium updated divided by its stoichiometric coefficient
  let c (mn-useful / 0.3250)                                           ; uptaken nitric oxide updated divided by its stoichiometric coefficient

  let x3 min (list a b c)                                              ; limiting nutrient for enzimatic reaction 3 on pathway 3 in anaerobic phase

  let nbiomass 0.0551 * x3                                             ; Biomass generation for enzimatic reaction 3 on pathway 3 [mmol]
  let ndioxide 0.0189 * x3                                             ; Carbon dioxide generation for enzimatic reaction 3 on pathway 3 [mmol]
  let ndinitrogen 0.1625 * x3                                          ; Nitrous oxide generation for enzimatic reaction 3 on pathway 3 [mmol]
  let nbicarbonate 0.1015 * x3                                         ; Bicarbonate generation for enzimatic reaction 3 on pathway 3 [mmol]
  set biomass (biomass + nbiomass)                                     ; Individual biomass update
  set dioxide (dioxide + ndioxide)                                     ; Carbon dioxide local quantity update
  set bicarbonate (bicarbonate + nbicarbonate)                         ; Bicarbonate local quantity update
  set dn-useful (dn-useful + ndinitrogen)                              ; Update of nitrous oxide uptaken

  set sc-useful (sc-useful - 0.0714 * x3)                              ; update electron donor bacterium quantity
  set am-useful (am-useful - 0.0413 * x3)                              ; update N-source bacterium quantity
  set mn-useful (mn-useful - 0.3250 * x3)                              ; update electron aceptor bacterium quantity
  set s_anox_3 s_anox_3 + 1                                            ; counter to third biomass synthesis reaction on anaerobic phase

  if (sc-useful > 0) and (am-useful > 0) and (dn-useful > 0)[anoxic4]  ; if the succinate, amonium and nitrous oxide quatities are enough go to enzimatic reaction 4
end

; _____________________________ Biomass Synthesis to anoxic reaction 4 ___________________________________________________________________________________________

to anoxic4 ; 0.0714 (C4H4O4)2- + 0.0413 NH4+ + 0.1625 N2O ->  0.0551 C3H5.4N0.75O1.45 + 0.1625 N2 + 0.0189 CO2 + 0.1015 HCO3- + 0.0260 H2O adjusted by TEEM2 (McCarty, 2007)

  let a (sc-useful / 0.0714)                                         ; uptaken succinate updated divided by its stoichiometric coefficient
  let b (am-useful / 0.0413)                                         ; uptaken amonium updated divided by its stoichiometric coefficient
  let c (dn-useful / 0.1625)                                         ; uptaken nitrous oxide updated divided by its stoichiometric coefficient

  let x4 min (list a b c)                                            ; limiting nutrient for enzimatic reaction 4 on pathway 3 in anaerobic phase

  let nbiomass 0.0551 * x4                                           ; Biomass generation for enzimatic reaction 4 on pathway 3 [mmol]
  let ndioxide 0.0189 * x4                                           ; Carbon dioxide generation for enzimatic reaction 4 on pathway 3 [mmol]
  let nnitrogen 0.1625 * x4                                          ; Nitrogen gas generation for enzimatic reaction 4 on pathway 3 [mmol]
  let nbicarbonate 0.1015 * x4                                       ; Bicarbonate generation for enzimatic reaction 4 on pathway 3 [mmol]
  set biomass (biomass + nbiomass)                                   ; Individual biomass update
  set dioxide (dioxide + ndioxide)                                   ; Carbon dioxide local quantity update
  set bicarbonate (bicarbonate + nbicarbonate)                       ; Bicarbonate local quantity update
  set nitrogen (nitrogen + nnitrogen)                                ; Nitrogen gas local quantity update

  set sc-useful (sc-useful - 0.0714 * x4)                            ; update electron donor bacterium quantity
  set am-useful (am-useful - 0.0413 * x4)                            ; update N-source bacterium quantity
  set dn-useful (dn-useful - 0.1625 * x4)                            ; update electron aceptor bacterium quantity
  set s_anox_4 s_anox_4 + 1                                          ; counter to fourth biomass synthesis reaction on anaerobic phase
end

; ____________________________ Procedure before bipartition _______________________________________________________________________________________________

to metabolism_end
  ifelse sc-useful > 0 [set succinate-medium (succinate-medium + sc-useful) set sc-useful 0][set sc-useful 0]   ; Release to culture medium the quantity not used
  ifelse am-useful > 0 [set amonium-medium (amonium-medium + am-useful) set am-useful 0][set am-useful 0]       ; Release to culture medium the quantity not used
  ifelse ox-useful > 0 [set oxygen-medium (oxygen-medium + ox-useful) set ox-useful 0][set ox-useful 0]         ; Release to culture medium the quantity not used
  ifelse ntr-useful > 0 [set nitrate-medium (nitrate-medium + ntr-useful) set ntr-useful 0][set ntr-useful 0]   ; Release to culture medium the quantity not used
  ifelse nr-useful > 0 [set nitrite-medium (nitrite-medium + nr-useful) set nr-useful 0][set nr-useful 0]       ; Release to culture medium the quantity not used
  ifelse mn-useful > 0 [set monoxide-medium (monoxide-medium + mn-useful) set mn-useful 0][set mn-useful 0]     ; Release to culture medium the quantity not used
  ifelse dn-useful > 0 [set dinitrogen-medium (dinitrogen-medium + dn-useful) set dn-useful 0][set dn-useful 0] ; Release to culture medium the quantity not used
  set sc-mant2 0 set sc-mant3 0 set sc-mant4 0                                                                  ; Update to zero succinate internal maintenance requirements
end

; ____________________________ Bipartition Procedure _______________________________________________________________________________________________

to bipartition
  if biomass >= biomass-reproduction                                ; cell division happens when a treshold value is reached
  [
    let division-proportioning random-normal 0.50 (DSTr * 0.50)     ; new bacteria differ randomly in their cell-biomass
    let cell-biomass-1 biomass * division-proportioning             ; original biomass is not splitted equally into two halfs
    let cell-biomass-2 biomass - cell-biomass-1
    set biomass cell-biomass-1                                      ; biomass for original microorganims
    set biomass-reproduction abs random-normal (rep_biomass) (DSTr * rep_biomass)   ; setup new reproduction treshold for the original microorganism
    hatch 1                                                         ; born new microorganism
    [
      set biomass cell-biomass-2                                    ; biomass for newest microorganims
      set color green
      set R 0 set m_aero 0 set s_aero_1 0 set s_aero_2 0            ; Reset all counters for new microorganism
      set m_anox_1 0 set m_anox_2 0 set m_anox_3 0 set m_anox_4 0   ; Reset all counters for new microorganism
      set s_anox_1 0 set s_anox_2 0 set s_anox_3 0 set s_anox_4 0   ; Reset all counters for new microorganism
      set biomass-reproduction abs random-normal (rep_biomass) (DSTr * rep_biomass) ; setup the reproduction treshold for the newest microorganism
    ]
    set R R + 1                                                     ; Counter for bipartitions
  ]
end

; ____________________________ Proceeding to simulate bioreactor agitation over the microorganism ____________________________________________________

to move
  if q = 0
  [ setxy random-xcor random-ycor ] ; Randomly change position because bioreactor agitation
end

; ____________________________ Proceeding to setup and write bioreactor graphical outputs ____________________________________________________

to do-plotting
  setup-monitors

  set-current-plot "Biomass"
  set-current-plot-pen "Biomass"
  plotxy time_now gbacteria

  set-current-plot "Products-CO2"
  set-current-plot-pen "CO2"
  plotxy time_now gdioxide

  set-current-plot "Products-N2O"
  set-current-plot-pen "N2O"
  plotxy time_now gn2o

  set-current-plot "Products - NO2-"
  set-current-plot-pen "NO2-"
  plotxy time_now gno2-

  set-current-plot "Products - NO"
  set-current-plot-pen "NO"
  plotxy time_now gno

  set-current-plot "Products - N2"
  set-current-plot-pen "N2"
  plotxy time_now gn2

  set-current-plot "Culture Medium Nutrients"
  set-current-plot-pen "Succinate"
  plotxy time_now gsuccinate
  set-current-plot-pen "Amonium"
  plotxy time_now gamonium

  set-current-plot "Nitrate"
  set-current-plot-pen "nitrate"
  plotxy time_now gnitrate

  set-current-plot "Oxygen"
  set-current-plot-pen "oxygen"
  plotxy time_now goxygen * 32

  set-current-plot "Bicarbonate"
  set-current-plot-pen "bicarbonate"
  plotxy time_now gbicarbonate

  set-current-plot "Bacterial-biomass-distribution"
  set-current-plot-pen "biomass-histogram"
  histogram [biomass] of bacteria
  set-plot-pen-interval 0.1
end
@#$#@#$#@
GRAPHICS-WINDOW
8
10
274
297
-1
-1
9.85
1
10
1
1
1
0
1
1
1
0
25
0
25
1
1
1
Step time
30.0

SLIDER
8
306
180
339
Succinate
Succinate
0
20
20
0.1
1
[ mM ]
HORIZONTAL

SLIDER
8
342
180
375
Amonium
Amonium
0
15
10
0.1
1
[ mM ]
HORIZONTAL

MONITOR
8
525
102
570
Succinate [mM]
gsuccinate
6
1
11

MONITOR
101
525
173
570
NH4+ [mM]
gamonium
3
1
11

MONITOR
172
525
239
570
O2 [mg/l]
goxygen * 32
3
1
11

SLIDER
279
152
441
185
Microrganism
Microrganism
1
500
8
1
1
bacteria
HORIZONTAL

MONITOR
780
525
880
570
Biomass [mg/ml]
gbacteria
5
1
11

PLOT
8
822
399
1075
Products-CO2
Time [hours]
Concentration [ mM ]
0.0
120.0
0.0
0.01
true
false
"" ""
PENS
"CO2" 1.0 2 -14070903 true "" ""

SLIDER
8
378
180
411
Nitrate
Nitrate
0
25
4.99825
0.1
1
[ mM ]
HORIZONTAL

MONITOR
238
525
314
570
NO3- [mM]
gnitrate
3
1
11

PLOT
794
822
1184
1076
Culture Medium Nutrients
Time [hours]
Concentration[ mM ]
0.0
120.0
0.0
10.0
true
true
"" ""
PENS
"Succinate" 1.0 2 -14454117 true "" ""
"Amonium" 1.0 2 -15302303 true "" ""

PLOT
445
248
821
484
Products - NO2-
Time [hours]
Concentration [ mM ]
0.0
120.0
0.0
0.0
true
false
"" ""
PENS
"NO2-" 1.0 2 -7858858 true "" ""

PLOT
445
11
821
249
Biomass
Time [hours]
Biomass [mg/ml]
0.0
120.0
0.0
0.0
true
false
"" ""
PENS
"Biomass" 1.0 2 -2674135 true "" ""

SLIDER
280
268
444
301
NOX
NOX
0.01
0.3125
0.02
0.01
1
[ mM O2 ]
HORIZONTAL

MONITOR
385
525
452
570
NO [mM]
gno
3
1
11

MONITOR
313
525
386
570
NO2- [mM]
gno2-
3
1
11

MONITOR
589
525
664
570
CO2 [mM]
gdioxide
3
1
11

MONITOR
451
525
526
570
N2O [uM]
gn2o
3
1
11

MONITOR
525
525
590
570
N2 [mM]
gn2
3
1
11

PLOT
400
572
792
821
Products - NO
Time [hours]
Concentration [ mM ]
0.0
120.0
0.0
0.01
true
false
"" ""
PENS
"NO" 1.0 2 -12087248 true "" ""

PLOT
822
247
1195
484
Products-N2O
Time [hours]
Concentration[ uM ]
0.0
120.0
0.0
0.0
true
false
"" ""
PENS
"N2O" 1.0 2 -13345367 true "" ""

SLIDER
184
307
437
340
Simulation_Time
Simulation_Time
0
250
120
1
1
[ hours ]
HORIZONTAL

PLOT
794
572
1184
820
Products - N2
Time [hours]
Concentration [ mM ]
0.0
120.0
0.0
0.001
true
false
"" ""
PENS
"N2" 1.0 2 -2674135 true "" ""

MONITOR
878
525
961
570
Time [hours]
time_now
2
1
11

SLIDER
103
415
195
448
uSc
uSc
0
0.52
0.52
0.01
1
NIL
HORIZONTAL

SLIDER
8
415
100
448
nsc
nsc
0
1
0.28
0.01
1
NIL
HORIZONTAL

SLIDER
280
230
444
263
Min/steptime
Min/steptime
1
60
5
1
1
[min]
HORIZONTAL

SLIDER
184
343
437
376
Time_Shutdown_O2
Time_Shutdown_O2
1
48
24
1
1
[hours]
HORIZONTAL

SWITCH
279
112
442
145
Output_file?
Output_file?
1
1
-1000

MONITOR
663
525
732
570
Individuals
count bacteria
0
1
11

BUTTON
285
19
351
52
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
366
19
429
52
Go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
222
379
314
412
nntr
nntr
0
1
0.63
0.01
1
NIL
HORIZONTAL

SLIDER
322
379
437
412
uNO3-x
uNO3-x
0
1.19
0.119
0.001
1
NIL
HORIZONTAL

SLIDER
247
416
339
449
nnr
nnr
0
1
0.79
0.01
1
NIL
HORIZONTAL

SLIDER
344
416
436
449
uNO2-
uNO2-
0
0.62
0.062
0.01
1
NIL
HORIZONTAL

SLIDER
247
453
339
486
nmn
nmn
0
1
1
0.01
1
NIL
HORIZONTAL

SLIDER
344
453
436
486
uNO
uNO
0
0.62
0.62
0.0001
1
NIL
HORIZONTAL

PLOT
8
572
399
821
Oxygen
Time [hours]
Concentration [mg/l]
0.0
120.0
0.0
10.0
true
false
"" ""
PENS
"oxygen" 1.0 2 -955883 true "" ""

PLOT
822
10
1195
247
Nitrate
Time [hours]
Concentration [mM]
0.0
120.0
0.0
0.0
true
false
"" ""
PENS
"nitrate" 1.0 2 -10141563 true "" ""

SLIDER
446
488
699
521
energy_maintenance_a
energy_maintenance_a
0
0.03
0.002
0.0001
1
[g C/gCm h]
HORIZONTAL

MONITOR
731
525
781
570
Die Bac
bacteriaout
0
1
11

SLIDER
247
488
339
521
ndn
ndn
0
1
0.5
0.01
1
NIL
HORIZONTAL

SLIDER
343
489
435
522
uN2O
uN2O
0
0.31
0.31
0.01
1
NIL
HORIZONTAL

MONITOR
960
525
1017
570
NIL
d
3
1
11

SLIDER
280
192
444
225
di
di
0
0.1
0.05
0.01
1
[ 1/h ]
HORIZONTAL

SLIDER
7
487
99
520
nx
nx
0
1
0.79
0.01
1
NIL
HORIZONTAL

SLIDER
102
488
194
521
uox
uox
0
0.54
0.54
0.01
1
NIL
HORIZONTAL

SLIDER
102
452
194
485
uam
uam
0
0.31
0.31
0.01
1
NIL
HORIZONTAL

SLIDER
7
451
99
484
nam
nam
0
1
0.84
0.01
1
NIL
HORIZONTAL

PLOT
796
1335
1185
1583
Metabolic reactions
NIL
NIL
0.0
120.0
0.0
10.0
true
true
"" ""
PENS
"m_aero" 1.0 0 -1184463 true "" "plotxy time_now sum [m_aero] of bacteria"
"s_aero_1" 1.0 0 -14070903 true "" "plotxy time_now sum[s_aero_1] of bacteria"
"m_anox_1" 1.0 0 -7500403 true "" "plotxy time_now sum [m_anox_1] of bacteria"
"m_anox_2" 1.0 0 -2674135 true "" "plotxy time_now sum [m_anox_2] of bacteria"
"m_anox_3" 1.0 0 -955883 true "" "plotxy time_now sum [m_anox_3] of bacteria"
"m_anox_4" 1.0 0 -6459832 true "" "plotxy time_now sum [m_anox_4] of bacteria"
"s_anox_1" 1.0 0 -8630108 true "" "plotxy time_now sum [s_anox_1] of bacteria"
"s_anox_2" 1.0 0 -11221820 true "" "plotxy time_now sum [s_anox_2] of bacteria"
"s_anox_3" 1.0 0 -13840069 true "" "plotxy time_now sum [s_anox_3] of bacteria"
"s_anox_4" 1.0 0 -12186836 true "" "plotxy time_now sum [s_anox_4] of bacteria"
"s_aero_2" 1.0 0 -5825686 true "" "plotxy time_now sum[s_aero_2] of bacteria"

PLOT
400
822
792
1075
Bicarbonate
Time [hours]
Concentration [mM]
0.0
120.0
0.0
0.0
true
false
"" ""
PENS
"bicarbonate" 1.0 2 -2674135 true "" ""

CHOOSER
280
59
440
104
Experiment
Experiment
"Succ_High/Nitrate_Low" "Succ_Low/Nitrate_High"
0

MONITOR
9
1081
150
1126
Succinate-ini (mmol)
isuccinate
3
1
11

MONITOR
9
1124
151
1169
Amonium-ini (mmol)
iamonium
3
1
11

MONITOR
9
1167
151
1212
oxygen-ini (mmol)
ioxygen
3
1
11

MONITOR
9
1210
151
1255
Nitrate-ini (mmol)
initrate
3
1
11

MONITOR
9
1253
151
1298
Nitrite-ini (mmol)
initrite
3
1
11

MONITOR
9
1295
151
1340
Monoxide-ini (mmol)
imonoxide
3
1
11

MONITOR
9
1337
151
1382
N2O-ini (mmol)
idinitrogen
3
1
11

MONITOR
9
1425
151
1470
CO2-ini (mmol)
idioxide
3
1
11

MONITOR
9
1511
151
1556
HCO3-ini (mmol)
ibicarbonate
3
1
11

MONITOR
9
1468
151
1513
Biomass-ini (mmol)
ibacteria
3
1
11

MONITOR
9
1380
151
1425
N2-ini (mmol)
initrogen
3
1
11

MONITOR
150
1081
288
1126
∆Succinate (mmol)
fsuccinate - isuccinate
4
1
11

MONITOR
149
1124
288
1169
∆Amonium (mmol)
famonium - iamonium
4
1
11

MONITOR
149
1167
288
1212
∆Oxygen (mmol)
foxygen - ioxygen
4
1
11

MONITOR
149
1210
288
1255
∆Nitrate (mmol)
fnitrate - initrate
4
1
11

MONITOR
149
1252
288
1297
∆Nitrite (mmol)
fnitrite - initrite
4
1
11

MONITOR
149
1295
288
1340
∆NO (mmol)
fmonoxide - imonoxide
4
1
11

MONITOR
151
1424
287
1469
∆CO2 (mmol)
fdioxide - idioxide
4
1
11

MONITOR
151
1380
287
1425
∆N2 (mmol)
fnitrogen - initrogen
4
1
11

MONITOR
150
1512
289
1557
∆HCO3- (mmol)
fbicarbonate - ibicarbonate
4
1
11

MONITOR
150
1468
288
1513
∆Biomass (mmol)
fbacteria - ibacteria
4
1
11

MONITOR
149
1337
288
1382
∆N2O (mmol)
fdinitrogen - idinitrogen
4
1
11

MONITOR
286
1081
449
1126
Succinate-inflow (mmol)
insuccinate
3
1
11

MONITOR
286
1123
449
1168
Amonium-inflow (mmol)
inamonium
3
1
11

MONITOR
287
1210
450
1255
Nitrate-inflow (mmol)
innitrate
3
1
11

MONITOR
448
1081
595
1126
Succinate-out (mmol)
outsuccinate
4
1
11

MONITOR
447
1123
595
1168
Amonium-out (mmol)
outamonium
4
1
11

MONITOR
450
1210
598
1255
Nitrate-out (mmol)
outnitrate
4
1
11

MONITOR
451
1253
598
1298
Nitrite-out (mmol)
outnitrite
4
1
11

MONITOR
451
1296
598
1341
NO-out (mmol)
outmonoxide
4
1
11

MONITOR
451
1338
598
1383
N2O-out (mmol)
outdinitrogen
4
1
11

MONITOR
451
1381
598
1426
N2-out (mmol)
outnitrogen
4
1
11

MONITOR
451
1424
598
1469
CO2-out (mmol)
outdioxide
4
1
11

MONITOR
451
1467
598
1512
Bacteria-out (mmol)
outbacteria
4
1
11

MONITOR
451
1511
598
1556
HCO3-out (mmol)
outbicarbonate
4
1
11

MONITOR
597
1468
700
1513
c-Mic [mg]
c-bacteria
2
1
11

MONITOR
699
1468
782
1513
N-bac [mg]
n-bacteria
2
1
11

MONITOR
594
1081
714
1126
C-Succinate (mg)
c-succinate
2
1
11

MONITOR
594
1123
715
1168
N-Amonium (mg)
n-amonium
2
1
11

MONITOR
598
1210
700
1255
n-Nitrate (mg)
n-nitrate
2
1
11

MONITOR
598
1253
700
1298
n-Nitrite (mg)
n-nitrite
2
1
11

MONITOR
598
1295
700
1340
n-NO (mg)
n-monoxide
2
1
11

MONITOR
598
1338
700
1383
N-N2O (mg)
n-dinitrogen
2
1
11

MONITOR
598
1381
700
1426
N-N2 (mg)
n-nitrogen
2
1
11

MONITOR
598
1424
700
1469
c-CO2 (mg)
c-co2
2
1
11

MONITOR
597
1511
702
1556
c-HCO3 (mg)
c-hco3
2
1
11

MONITOR
308
1273
421
1318
c-obtained (mg)
c-obtained
2
1
11

MONITOR
308
1318
421
1363
c-delivered (mg)
c-delivered
2
1
11

MONITOR
310
1446
424
1491
n-obtained (mg)
n-obtained
2
1
11

MONITOR
311
1491
424
1536
n-delivered (mg)
n-delivered
2
1
11

MONITOR
1015
525
1072
570
%eC
%_e_c
2
1
11

MONITOR
1070
525
1127
570
%eN
%_e_n
2
1
11

SLIDER
703
489
963
522
energy_maintenance_x
energy_maintenance_x
0
0.03
0.004
0.001
1
[gC/gCm h]
HORIZONTAL

MONITOR
1126
525
1183
570
Yc/c
yc/c
3
1
11

PLOT
795
1078
1185
1333
Bacterial-biomass-distribution
Cell-Biomass
Frequency
1.0
6.0
0.0
0.0
true
false
"" ""
PENS
"biomass-histogram" 1.0 1 -16777216 true "" ""

PLOT
796
1584
1186
1833
%eC / %eN / d
NIL
NIL
0.0
120.0
0.0
0.0
true
true
"" ""
PENS
"d" 1.0 2 -16777216 true "" "plotxy time_now d"
"%eC" 1.0 2 -2674135 true "" "plotxy time_now %_e_c"
"%eN" 1.0 2 -13345367 true "" "plotxy time_now %_e_n"

SLIDER
985
488
1084
521
uNO3-a
uNO3-a
0
0.27
0.27
0.001
1
NIL
HORIZONTAL

SLIDER
1092
488
1185
521
k_avail
k_avail
0
1
0.3
0.01
1
NIL
HORIZONTAL

MONITOR
557
1786
737
1831
Time [min] since open NetLogo
timer / 60
1
1
11

MONITOR
556
1736
689
1781
Simulated_time [ s ]
Pablo
2
1
11

BUTTON
554
1694
620
1727
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
624
1694
687
1727
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

@#$#@#$#@
## INDISIM-PARACOCCUS ([Araujo Granda P.A., Gras A., Ginovart M. & Moulton V. - 2016](http://www.sciencedirect.com/science/article/pii/S0022519316300959))

## WHAT IS IT?

Modeling a bioreactor to grow P. denitrificans in a culture medium with succinate, as electron donor and C-source, ammonium (NH4+) as N-source and various electron acceptors as O2, NO3-, NO2-, NO and N2O, in order to simulate denitrification experiments in batch and continuous culture for identify factors in the simulated metabolism or culture medium, which are significant to the dynamics of denitrification products, especially greenhouse gas N2O.

## HOW IT WORKS (what rules the agents use to create the overall behavior of the model)

The overall behavior of the model is create when agents use 4 basic behavior-rules: a) Uptake b) Cellular maintenance c) Biomass generation and d) Bipartition. These rules have special protocols, they are:
1) Individual biomass changes are possible if microorganism executes any of the six metabolic pathways adjusted by TEEM2.
2) The nutrient uptake capacity is accord to individual biomass and update each time step with the biomass changes.
3) The intake nutrient emerge from the lowest value between nutrient availability and nutrient uptake.
4) Cellular maintenance value is appropriate requirement for heterotrophic microorganisms and its different for aerobic and anaerobic phase. 5) Bipartition is accord to binary fission in bacteria.
6) Agitation, batch culture, continuous culture and dilution ratio are the chemostat general procedures.
P. denitrificans is the only bacterium in the bioreactor and only interacts with the culture medium. Simulated microorganisms do not develop aggregates; each individual acts uniquely. The individual identifies its biomass and uptake capacities. With this information the agent compare their uptake capacities with the nutrients availability and takes the lowest value as your nutrient intake. The first decision-making agent is about the response to the O2 dissolved level in the culture medium, if the O2 dissolved level is lower than NOX value the agent execute anaerobic metabolism and if is higher the agent execute aerobic metabolism. The second decision-making agent is performing metabolic pathways for growth and bio-product synthesis only if that reached their cellular maintenance in aerobic or anaerobic phase. The third decision-making agent is about reproduction that means not to make bipartitions if that has not reached the minimum reproduction mass.

## HOW TO USE IT (how to use the model, including a description of each of the items in the Interface tab)

The simulator NetLogo interface makes it easy to change initial values via sliders. The user can adjust:
1) Nutrient concentrations: [mM] for succinate, ammonium and nitrate these values are determined from the normal distribution of which mean value is according to the experimental procedure with standard deviation of 5% mean value for each nutrient. The initial nutrient concentration (batch culture) is the same for the reservoir medium feed (continuos culture).
2) NOX value [mM]: which is fixed by the user in the range of 0.01 to 0.31 mM O2 and is determined from the normal distribution of which mean is that fixed value with standard deviation of 5% mean value. If the O2 dissolved level is lower than NOX value the agent execute anaerobic metabolism and if is higher the agent execute aerobic metabolism.
3) Time shutdown O2 [h]: With this slider the user can adjust the aerobic phase time. If the simulation time is lower than “time shutdown O2” the bioreactor works in aerobic batch culture. If the simulation time is highest than “time shutdown O2” the aeration was then switched off and the system switched to continuous culture with a dilution rate adjusted by user.
4) Dilution ratio [1/h]: The user can adjust this value for the continuous culture.
5) Microorganism [microbes]: Initial amount of viable microorganisms (P. denitrificans bacteria).
6) Simulation time [h]: with this slider the user can adjust te total time for simulation experiments.
7) Step time [min]: INDISIM-Paracoccus is discrete in space and time, with this slider the user can stablished the time scale, one full program run is equal a one step time.
8) Nutrients availability (ni) [1/h]: Is possible adjust the maximum nutrient availability for the total of chemical species (nutrients and denitrification products). Succinate, ammonium, nitrate, nitrite, nitric oxide and nitrous oxide. ni a number between 0 and 1 that indicates the fraction of the total nutrient in culture medium is available for the individuals living in the spatial unit. This parameter is directly related to the culture medium characteristics and not to the types of microorganisms involved.
9) Nutrients uptake rates (ui) [mol/mol·h]: Is possible adjust the maximum microbial uptake rate for each nutrient. ui is the amount of nutrient per unit of time, that a microorganism could use under non-limiting nutrient availability and is correlated with the individual biomass. This value is a microscopic parameter directly related to the type of microorganism involved.
10) Maintenance energy requirement [gC/gCm·h]: Before biomass generation, it is necessary that the microorganism complete its basal metabolism in order to keep its structures. The user can adjust the value for anaerobic phase
11) Input data: Normal functioning external files are not necessary for the model to run simulated procedures.
12) The graphical and numerical outputs of the model are the concentration [mM or uM] of each culture medium component (succinate, NH4+, O2, NO3- CO2, NO2-, NO, N2O and N2) and microbial biomass [mg/ml] each time step. Additionally the user could obtain all simulated data in output file with extension “.txt”.

## THINGS TO NOTICE (suggested things for the user to notice while running the model)

After the setup procedure while running the model the user wait for the results and is interest observed the turtles (simulated active P. denitrificans bacteria) by click on it and see how the internal counters for each metabolic pathway change and the number of  generations the individual has.

## THINGS TO TRY (suggested things for the user to try to do (move sliders, switches, etc.) with the model)

To study the denitrification dynamics the user can move the uptake sliders and the step time scale proposed. In batch aerobic cultures the individual could execute 2 metabolic pathways each step time. To continuos culture the individual could execute 4 metabolic pathways each step time. Also the culture medium concentration for experiments with nutrient-limited. The overall simulation time. The maintenance energy requirement. To study the direct effect of some time dependent variables is possible realize any behavior-space experiments.

## EXTENDING THE MODEL (suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

The further works points out make adjustments in order to be closer of the denitrification enzymes concentration as a response of theenvironmental conditions.

## NETLOGO FEATURES (interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

Our model uses the general NetLogo commands, reportes and basic agentsets

## RELATED MODELS (models in the NetLogo Models Library and elsewhere which are of related interest)

Those models that simulate biological systems.

## CREDITS AND REFERENCES
![CC BY-NC-SA 4.0](http://ccl.northwestern.edu/images/creativecommons/byncsa.png)

INDISIM-Paracoccus – NetLogo’s Implementation by [Araujo Granda P.A., Gras A., Ginovart M. and Moulton V.](http://www.pablo.araujo.ec/?page_id=129) is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/4.0/">Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License</a>.

Corresponding author: e-mail: paraujo@iquce.edu.ec or pablo@araujo.ec , telephone: (34) 636261560
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="(FA) uNO3-a y uSc (ScHigh)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO3-a">
      <value value="0.034"/>
      <value value="0.068"/>
      <value value="0.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uSc">
      <value value="0.065"/>
      <value value="0.13"/>
      <value value="0.52"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(FA) uNO3-a y uSc (ScLow)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO3-a">
      <value value="0.034"/>
      <value value="0.068"/>
      <value value="0.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uSc">
      <value value="0.065"/>
      <value value="0.13"/>
      <value value="0.52"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO3-x y uSc (ScHigh)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO3-x">
      <value value="0.0119"/>
      <value value="0.119"/>
      <value value="1.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uSc">
      <value value="0.065"/>
      <value value="0.13"/>
      <value value="0.52"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO3-x y uSc (ScLow)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO3-x">
      <value value="0.0119"/>
      <value value="0.119"/>
      <value value="1.19"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uSc">
      <value value="0.065"/>
      <value value="0.13"/>
      <value value="0.52"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO3-x y uNO2- (ScLow)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO2-">
      <value value="0.0062"/>
      <value value="0.062"/>
      <value value="0.62"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO3-x">
      <value value="0.0119"/>
      <value value="0.119"/>
      <value value="1.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO3-x y uNO2- (ScHigh)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO2-">
      <value value="0.0062"/>
      <value value="0.062"/>
      <value value="0.62"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO3-x">
      <value value="0.0119"/>
      <value value="0.119"/>
      <value value="1.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO3-x y uNO (ScLow)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO">
      <value value="6.2E-6"/>
      <value value="6.2E-4"/>
      <value value="0.62"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO3-x">
      <value value="0.0119"/>
      <value value="0.119"/>
      <value value="1.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO3-x y uNO (ScHigh)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO">
      <value value="6.2E-6"/>
      <value value="6.2E-4"/>
      <value value="0.62"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO3-x">
      <value value="0.0119"/>
      <value value="0.119"/>
      <value value="1.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO3-x y uN2O (ScLow)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uN2O">
      <value value="0.0031"/>
      <value value="0.031"/>
      <value value="0.31"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO3-x">
      <value value="0.0119"/>
      <value value="0.119"/>
      <value value="1.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO3-x y uN2O (ScHigh)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uN2O">
      <value value="0.0031"/>
      <value value="0.031"/>
      <value value="0.31"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO3-x">
      <value value="0.0119"/>
      <value value="0.119"/>
      <value value="1.19"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO2-x y uNO (ScLow)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO">
      <value value="6.2E-6"/>
      <value value="6.2E-4"/>
      <value value="0.62"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO2-">
      <value value="0.0062"/>
      <value value="0.062"/>
      <value value="0.62"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO2-x y uNO (ScHigh)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO">
      <value value="6.2E-6"/>
      <value value="6.2E-4"/>
      <value value="0.62"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO2-">
      <value value="0.0062"/>
      <value value="0.062"/>
      <value value="0.62"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO2-x y uN2O (ScHigh)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uN2O">
      <value value="0.0031"/>
      <value value="0.031"/>
      <value value="0.31"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO2-">
      <value value="0.0062"/>
      <value value="0.062"/>
      <value value="0.62"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uNO2-x y uN2O (ScLow)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uN2O">
      <value value="0.0031"/>
      <value value="0.031"/>
      <value value="0.31"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO2-">
      <value value="0.0062"/>
      <value value="0.062"/>
      <value value="0.62"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uN2O y uNO (ScHigh)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO">
      <value value="6.2E-6"/>
      <value value="6.2E-4"/>
      <value value="0.62"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uN2O">
      <value value="0.0031"/>
      <value value="0.031"/>
      <value value="0.31"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="(Fx) uN2O y uNO (ScLow)" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>gbacteria</metric>
    <metric>gnitrate</metric>
    <metric>gno2-</metric>
    <metric>gn2o</metric>
    <metric>gsuccinate</metric>
    <metric>gno</metric>
    <metric>gn2</metric>
    <enumeratedValueSet variable="uNO">
      <value value="6.2E-6"/>
      <value value="6.2E-4"/>
      <value value="0.62"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uN2O">
      <value value="0.0031"/>
      <value value="0.031"/>
      <value value="0.31"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Variabilidad" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
  </experiment>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="Output_file?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO3-a">
      <value value="0.27"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nx">
      <value value="0.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Experiment">
      <value value="&quot;Succ_Low/Nitrate_High&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uam">
      <value value="0.31"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO2-">
      <value value="0.062"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Succinate">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_maintenance_x">
      <value value="0.004"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO3-x">
      <value value="0.119"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Nitrate">
      <value value="21.60951"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="energy_maintenance_a">
      <value value="0.002"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Min/steptime">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time_Shutdown_O2">
      <value value="24"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nntr">
      <value value="0.63"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Simulation_Time">
      <value value="120"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Microrganism">
      <value value="131"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uNO">
      <value value="0.62"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nsc">
      <value value="0.28"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uSc">
      <value value="0.52"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nnr">
      <value value="0.79"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ndn">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k_avail">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Amonium">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="NOX">
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uox">
      <value value="0.54"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nmn">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nam">
      <value value="0.84"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uN2O">
      <value value="0.31"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="di">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
